import React from 'react';
import { Text, View, Button, Picker } from '@ray-js/ray';
import {Svg, Icon} from '@ray-js/svg';
import { useActions, useDevInfo, useDpSchema, useProps } from "@ray-js/panel-sdk";
import styles from './topTemperatureView.module.less';
import Dialog from '@ray-js/components-ty-dialog';
import { TyTypography } from '@ray-js/components-ty';

export default function TopTemperatureView() {
    const dpSchema = useDpSchema();
    const dpState = useProps(state => state);
    const actions = useActions();

    const [showSetTempAlert, setShowSetTempAlert] = React.useState(false);
    const [alertTemp, setAlertTemp] = React.useState(0);

    const switch_power = dpState["switch"]
    const unit = dpState["temp_unit_convert"]
    const temp_c = dpState['temp_set']
    const temp_f = dpState['temp_set_f']

    const scope = 330
    // 根据温度调整圆弧弧长
    const stroke = () : number => {
        if (unit === "c") {
            return (temp_c-30)/30*scope
        } else if (unit === 'f') {
            return (temp_f-86)/54*scope
        } else {
            return 1
        }
    }
    // 根据温度调整温度颜色
    const tempColor = () : string => {
        if (!switch_power) {
            return '#666666'
        }
        const startColor = [46, 90, 255];
        const endColor = [255, 46, 46];
        const percentage = stroke()/330; 
        const interpolatedColor = startColor.map((start, i) => {
        return Math.round(start + percentage * (endColor[i] - start));
        });
        const interpolatedCssColor = `rgb(${interpolatedColor.join(',')})`;
        return interpolatedCssColor
    }

    const tempNum = () : string => {
        if (unit === "c") {
            return temp_c
        } else if (unit === 'f') {
            return temp_f
        } else {
            return "_ _"
        }
    }

    const tempUnit = () : string => {
        if (unit === "c") {
            return "℃"
        } else if (unit === 'f') {
            return "℉"
        } else {
            return "_ _"
        }
    }

    function directSetTemp(event) {
        if (unit==='c') {
            const temp = event.value+30
            if (temp>=50) {
                setAlertTemp(temp)
                setShowSetTempAlert(true)
            } else {
                actions['temp_set'].set(temp)
            }
        } else {
            const temp = event.value+86
            if (temp>=122) {
                setAlertTemp(temp)
                setShowSetTempAlert(true)
            } else {
                actions['temp_set_f'].set(temp)
            }
        }
    }

    function alertSetTemp() {
        if (unit==='c') {
            actions['temp_set'].set(alertTemp)
        } else {
            actions['temp_set_f'].set(alertTemp)
        }
    }



    const tempPickerRange_c = Array.from({ length: 31 }, (_, index) => index + 30);
    const tempPickerRange_f = Array.from({ length: 55 }, (_, index) => index + 86);
   
    console.log('circle stroke: ', stroke())
    const cricleView = (
        <View className={styles.newTempView}>
            <View className={styles.circle}>
                <Svg width="100%" height='100%' viewBox='0 0 160 160'>
                    <defs>
                    <linearGradient id="color" x1="100%" y1="100%" x2="0%" y2="0%">
                        <stop offset="0%"  stop-color="#2E5AFF" stop-opacity="1"/>
                        <stop offset="100%" stop-color="#FF2E2E" stop-opacity="1"/>
                    </linearGradient>
                    </defs>
                    <circle cx='80' cy='80' r='70' stroke='#efefef' stroke-width='18' fill='none' stroke-dasharray="330,300" stroke-linecap='round' transform="rotate(135, 80, 80)"/>
                    <circle cx='80' cy='80' r='70' stroke={switch_power?'url(#color)':'#282828'} stroke-width='13' fill='none' stroke-linecap='round' transform="rotate(135, 80, 80)" style={`stroke-dasharray: ${stroke()},900`}/>
                </Svg>
            </View>
            <View className={styles.tempAndIcons}>
                <Text className={styles.setTemp} onClick={() => {}}>Set Temperture</Text>
                <Picker 
                    disabled={!switch_power}
                    mode='selector'
                    range={unit==='c'?tempPickerRange_c:tempPickerRange_f}
                    value={unit==='c'?temp_c-30:temp_f-86}
                    cancelText='cancel'
                    confirmText='confirm'
                    onChange={directSetTemp}
                    style={{}}
                >
                    <View className={styles.temp} >
                        <Text className={styles.tempNum} style={{color: tempColor()}}>{tempNum()}</Text>
                        <Text className={styles.tempUnit} style={{color: tempColor()}}>{tempUnit()}</Text>
                    </View>
                </Picker>
            
                <View className={styles.icons}>
                    <Svg className={styles.icon} width='23px' height='23px' viewBox="0 0 20 20">
                        <path fill='#a5a5a5' d='m13.42,11.44c-.41-2.25-.33-3.61-.32-3.71l1.88.14s-.07,1.28.32,3.37c-.61.08-1.24.15-1.89.2m-9.16,1.92c-.3,1.05-.7,2.21-1.24,3.47l1.73.75c.64-1.46,1.09-2.81,1.41-4.01-.65-.06-1.28-.13-1.91-.21m5.74.38c-.32,0-.63-.01-.95-.02v4.52h1.89v-4.52c-.32,0-.62.02-.94.02m5.82-.38c.3,1.05.7,2.21,1.24,3.47l-1.73.75c-.64-1.46-1.09-2.81-1.42-4.01.65-.06,1.29-.13,1.91-.21m-4.87-1.8v-3.75h-1.89v3.75c.32,0,.62.02.95.02s.63-.01.94-.02m-4.29-.12c.41-2.25.32-3.61.32-3.71l-1.89.14s.07,1.28-.32,3.37c.61.08,1.24.15,1.89.2m4.63-7.27V1.77h-2.58v2.38c-3.88.12-6.21.92-6.21.92v1.03h15v-1.03c-2.27-.54-4.36-.8-6.21-.89'></path>
                    </Svg>
                    <Svg className={styles.icon} width='23px' height='23px' viewBox="0 0 20 20">
                        <path fill='#a5a5a5' d="m3.48,18.13l-.46-1.42c.1-.03,2.45-.85,2.45-3.2,0-1.27-.68-2.22-1.39-3.23-.77-1.09-1.57-2.23-1.57-3.79,0-3.18,3.29-4.55,3.43-4.6l.56,1.38s-2.5,1.05-2.5,3.22c0,1.09.6,1.95,1.3,2.93.78,1.1,1.66,2.35,1.66,4.09,0,2.76-2.27,4.23-3.48,4.62Z"/>
                        <path fill='#a5a5a5' d="m8.75,18.13l-.46-1.42c.1-.03,2.45-.85,2.45-3.2,0-1.27-.68-2.22-1.39-3.23-.77-1.09-1.57-2.23-1.57-3.79,0-3.18,3.29-4.55,3.43-4.6l.56,1.38s-2.5,1.05-2.5,3.22c0,1.09.6,1.95,1.3,2.93.78,1.1,1.66,2.35,1.66,4.09,0,2.76-2.27,4.23-3.48,4.62Z"/>
                        <path fill='#a5a5a5' d="m14.02,18.13l-.46-1.42c.1-.03,2.45-.85,2.45-3.2,0-1.27-.68-2.22-1.39-3.23-.77-1.09-1.57-2.23-1.57-3.79,0-3.18,3.29-4.55,3.43-4.6l.56,1.38s-2.5,1.05-2.5,3.22c0,1.09.6,1.95,1.3,2.93.78,1.1,1.66,2.35,1.66,4.09,0,2.76-2.27,4.23-3.48,4.62Z"/>
                    </Svg>
                    <Svg className={styles.icon} width='23px' height='23px' viewBox="0 0 20 20">
                        <path fill='#a5a5a5' d="m9.09,15.68l.9,1.48.89-1.46c-.55-.34-1.24-.35-1.8-.01Z"/>
                        <path fill='#a5a5a5' d="m13.19,11.94c-1.98-1.11-4.4-1.11-6.38,0l.9,1.48c1.42-.78,3.15-.78,4.57,0l.9-1.48Z"/>
                        <path fill='#a5a5a5' d="m15.46,8.22c-3.37-1.96-7.56-1.96-10.93,0l.9,1.48c2.81-1.63,6.29-1.6,9.1.02l.92-1.51Z"/>
                        <path fill='#a5a5a5' d="m16.59,6.36l.91-1.48c-4.61-2.72-10.39-2.72-15,.01l.9,1.48c4.06-2.39,9.13-2.4,13.19-.01Z"/>

                    </Svg>
                </View>
                
            </View>
            <Dialog 
                show={showSetTempAlert} 
                title='Please Confirm'
                subTitle={unit==='c'?'The setting temperature has exceeded 50℃.':'The setting temperature has exceeded 122℉.'} 
                actionDataSource={[
                    {
                        text: <TyTypography type="title" text="YES" />,
                        onClick: () => alertSetTemp()
                    },
                    {
                        text: <TyTypography type="title" text="NO" />,
                    }
                ]}                
            />
        </View>
    )

    return (
        cricleView
    )


}
